@@ -3,8 +3,8 @@
 
 #pragma once
 
-#include <KIdentityManagementQuick/CryptographyBackendInterface>
 #include <KIdentityManagementCore/Identity>
+#include <KIdentityManagementQuick/CryptographyBackendInterface>
 #include <QAbstractItemModel>
 
 class IdentityKeyListModel;
@@ -25,7 +25,7 @@ protected:
     void setIdentity(const KIdentityManagementCore::Identity &identity) override;
 
 private:
-    IdentityKeyListModel *m_openPgpKeyListModel = nullptr;
-    IdentityKeyListModel *m_smimeKeyListModel = nullptr;
+    IdentityKeyListModel *const m_openPgpKeyListModel;
+    IdentityKeyListModel *const m_smimeKeyListModel;
     KIdentityManagementCore::Identity m_identity;
 };
